<!DOCTYPE html><html lang="en"><head><meta charSet="utf-8"/><meta name="viewport" content="width=device-width"/><meta name="next-head-count" content="2"/><link data-next-font="" rel="preconnect" href="/" crossorigin="anonymous"/><link rel="preload" href="/_next/static/css/d78390d6134d8328.css" as="style"/><link rel="stylesheet" href="/_next/static/css/d78390d6134d8328.css" data-n-g=""/><noscript data-n-css=""></noscript><script defer="" nomodule="" src="/_next/static/chunks/polyfills-42372ed130431b0a.js"></script><script src="/_next/static/chunks/webpack-c2c11809187b9f84.js" defer=""></script><script src="/_next/static/chunks/framework-c92fc3344e6fd165.js" defer=""></script><script src="/_next/static/chunks/main-090643377c8254e6.js" defer=""></script><script src="/_next/static/chunks/pages/_app-ee588a308812715d.js" defer=""></script><script src="/_next/static/chunks/7630-a11610c2b31ab2ca.js" defer=""></script><script src="/_next/static/chunks/pages/notifications/templates/%5Bid%5D-8063dceb32310c85.js" defer=""></script><script src="/_next/static/BcQzR23eIPTcIJtpdoKEA/_buildManifest.js" defer=""></script><script src="/_next/static/BcQzR23eIPTcIJtpdoKEA/_ssgManifest.js" defer=""></script><style>.data-ant-cssinjs-cache-path{content:"";}</style></head><body><div id="__next"><div style="height:100%;display:flex"></div></div><script id="__NEXT_DATA__" type="application/json">{"props":{"pageProps":{}},"page":"/notifications/templates/[id]","query":{},"buildId":"BcQzR23eIPTcIJtpdoKEA","nextExport":true,"autoExport":true,"isFallback":false,"scriptLoader":[]}</script></body></html>